Actions, Resources, and Condition Keys for Amazon CloudWatch - AWS Identity and Access Management
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for Amazon CloudWatch

Amazon CloudWatch (service prefix: `cloudwatch` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon CloudWatch
- Resource Types Defined by Amazon CloudWatch
- Condition Keys for Amazon CloudWatch

## Actions Defined by Amazon CloudWatch

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
DeleteAlarms | Deletes all specified alarms. In the event of an error, no alarms are deleted | Write | alarm* |  |
DeleteAnomalyDetector | Deletes the specified anomaly detection model from your account. | Write |  |  |
DeleteDashboards | Deletes all CloudWatch dashboards that you specify | Write | dashboard* |  |
DeleteInsightRules | Grants permission to delete a collection of insight rules. | Write | insight-rule* |  |
DescribeAlarmHistory | Retrieves history for the specified alarm | Read | alarm* |  |
DescribeAlarms | Retrieves alarms with the specified names | Read | alarm* |  |
DescribeAlarmsForMetric | Retrieves all alarms for a single metric | Read |  |  |
DescribeAnomalyDetectors | Lists the anomaly detection models that you have created in your account. | Read |  |  |
DescribeInsightRules | Grants permission to describe all insight rules, currently owned by the user's account. | Read |  |  |
DisableAlarmActions | Disables actions for the specified alarms | Write | alarm* |  |
DisableInsightRules | Grants permission to disable a collection of insight rules. | Write | insight-rule* |  |
EnableAlarmActions | Enables actions for the specified alarms | Write | alarm* |  |
EnableInsightRules | Grants permission to enable a collection of insight rules. | Write | insight-rule* |  |
GetDashboard | Displays the details of the CloudWatch dashboard you specify | Read | dashboard* |  |
GetInsightRuleReport | Grants permission to return the top-N report of unique contributors over a time range for a given insight rule. | Read | insight-rule* |  |
GetMetricData | Required to retrieve batch amounts of CloudWatch metric data and perform metric math on retrieved data | Read |  |  |
GetMetricStatistics | Gets statistics for the specified metric | Read |  |  |
GetMetricWidgetImage | Required to retrieve snapshots of metric widgets | Read |  |  |
ListDashboards | Returns a list of all CloudWatch dashboards in your account | List |  |  |
ListMetrics | Returns a list of valid metrics stored for the AWS account owner | List |  |  |
ListTagsForResource | This action lists tags for an Amazon CloudWatch resource. | List | alarm* |  |
PutAnomalyDetector | Creates or updates an anomaly detection model for a CloudWatch metric. | Write |  |  |
PutDashboard | Creates a CloudWatch dashboard, or updates an existing dashboard if it already exists | Write | dashboard* |  |
PutInsightRule | Grants permission to create a new insight rule or replace an existing insight rule. | Write | insight-rule* |  |
PutMetricAlarm | Creates or updates an alarm and associates it with the specified Amazon CloudWatch metric | Write | alarm* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PutMetricData | Publishes metric data points to Amazon CloudWatch | Write |  | cloudwatch:namespace |
SetAlarmState | Temporarily sets the state of an alarm for testing purposes | Write | alarm* |  |
TagResource | This action tags an Amazon CloudWatch resource. | Tagging | alarm* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | This action removes a tag from an Amazon CloudWatch resource. | Tagging | alarm* |  |
| aws:TagKeys |

## Resource Types Defined by Amazon CloudWatch

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
alarm | `arn:$ { Partition}:cloudwatch:$ { Region}:$ { Account}:alarm:$ { AlarmName}` | aws:ResourceTag/${TagKey}
dashboard | `arn:$ { Partition}:cloudwatch::$ { Account}:dashboard/$ { DashboardName}` |
insight-rule | `arn:$ { Partition}:cloudwatch:$ { Region}:$ { Account}:insight-rule/$ { InsightRuleName}` |

## Condition Keys for Amazon CloudWatch

Amazon CloudWatch defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/$ { TagKey} | Filters actions based on the allowed set of values for each of the tags | String
aws:ResourceTag/$ { TagKey} | Filters actions based on tag-value associated with the resource | String
aws:TagKeys | Filters actions based on the presence of mandatory tags in the request | String
cloudwatch:namespace | Filters actions based on the presence of optional namespace values | String